<p align="center">
  <img src="https://avatars.githubusercontent.com/u/168782993?s=200&v=4">
</p>
  <h1 align="center">DoubleHelix</h1>

[![Build + Lint](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-build-lint.yml/badge.svg)](https://github.com/Helix/Helix/actions/workflows/python-build-lint.yml)
[![Python Publish](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-publish.yml/badge.svg)](https://github.com/Helix/Helix/actions/workflows/python-publish.yml/badge.svg)

[![PyInstaller release for Linux](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-pyinstaller-linux.yml/badge.svg)](https://github.com/Helix/Helix/actions/workflows/python-pyinstaller-linux.yml)
[![PyInstaller release for Windows](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-pyinstaller-win.yml/badge.svg)](https://github.com/Helix/Helix/actions/workflows/python-pyinstaller-win.yml)

This is my attempt to improve [WGSE](https://github.com/WGSExtract/WGSExtract-Dev). Still under heavy development. Don't expect anything working.

- [PyPi Package](https://pypi.org/project/Helix/)
- [Documentation](https://doublehelixapp.github.io/)

Follow [this](https://t.me/DoubleHelixApp) very low traffic telegram channel if you don't want to miss any updates on WGSE-NG (the channel is managed by [WGSE-NG Telegram bot](https://github.com/WGSE-NG/TelegramBOT)).

### Launch
The only currently supported way to install `Helix` is with a pypi package.

```bash
sudo apt install libqt6waylandclient6 samtools bcftools -y # Only for Linux
python -m pip install doublehelix
helix
```

NOTE: See the [doc](https://doublehelixapp.github.io/) for troubleshooting and for developer/user guides.
